@@ -8,8 +8,8 @@
 #ifndef CUSTOM_H
 #define	CUSTOM_H
 
-#define LINSSIDVERSION "2.9"
-#define LINSSIDPREFSVER "2.8"
+#define LINSSIDVERSION "3.6"
+#define LINSSIDPREFSVER "3.3"
 #define LINSSIDDATALOGVER "2.8"
 #define DATAWANTED QEvent::User + 1
 #define DATAREADY QEvent::User + 2
@@ -17,13 +17,10 @@
 #define MAX_SAMPLES 100
 #define TIME_PLOT_SCALE 100
 #define MAX_TABLE_COLS 19 // as of version 2.3
-#define VENDOR_FILE_NAME "/usr/share/linssid/oui.datb"
+#define VENDOR_FILE_NAME "/usr/share/linssid/oui.datc"
 #define PREFS_FILE_NAME ".linssid.prefs"
 #define LOG_DATA_FILE_NAME "LinSSID.datalog"
 
-enum passStatus {
-    GOOD, BAD, CANCELLED, NOTNEEDED
-};
 
 enum wlDriver {
     IOCTL, NL80211
@@ -42,5 +39,9 @@ enum pageBlockType {
     BT_VHT_CAPABILITIES, BT_VHT_OPERATION, BT_WPA, BT_WPS, BT_WMM
 };
 
+enum runStates {
+    STOPPED, STOPPING, RUNNING
+};
+
 
 #endif	/* CUSTOM_H */
