@@ -22,13 +22,12 @@
 #include "ui_MainForm.h"
 
 extern string pipeName;
-extern string password;
 extern qint64 startTime;
 extern string beginBlockString;
 extern string endBlockString;
 extern string pipeName;
-extern ofstream linssidLog;
-extern bool closing;
+// extern ofstream linssidLog;
+extern runStates runState;
 
 using namespace std;
 
@@ -83,33 +82,39 @@ void Getter::handleDataWantedEvent(const DataWantedEvent *event) {
     int blockNo = event->getWantedBlockNo();
     int rcSysCall = 0;
     ostringstream cppIsStupid;
-    cppIsStupid.str("");
-    cppIsStupid << " " << blockNo;
-    string lineCommand =
-            "echo \"" + beginBlockString + cppIsStupid.str() + "\\n\" >> " + pipeName;
-    if (pwStatus == NOTNEEDED) {
-        lineCommand += " && iw ";
-    } else {
-        lineCommand += " && echo \'" + password + "\' | sudo -kS -p \"\" iw ";
+    while (true) {
+        cppIsStupid.str("");
+        cppIsStupid << " " << blockNo;
+        string lineCommand = 
+                "echo \"" + beginBlockString + cppIsStupid.str() + "\" >> " + pipeName;
+//                "echo \"" + beginBlockString + cppIsStupid.str() + "\\n\" >> " + pipeName;
+        lineCommand += " ; iw ";
+        lineCommand += Getter::pMainForm->getCurrentInterface() + " scan >> " + pipeName;
+        for (int retries = 0; retries < 10; retries++) {
+            rcSysCall = system(lineCommand.c_str());
+            if ((rcSysCall == 0) || (runState == STOPPING)) break;
+            else QThread::msleep(500); // wait 500 msec and try again
+        }
+        if (rcSysCall != 0) { // retries exhausted on multiple failures
+            endCommand = "echo \"" + endBlockString + " -1\\n\" >> " + pipeName;
+            // linssidLog << "Getter: command failed block " << blockNo << endl;
+        } else { // success!
+            endCommand = "echo \"" + endBlockString + cppIsStupid.str() + "\\n\" >> " + pipeName;
+            // linssidLog << "Getter: block returned " << blockNo << endl;
+        }
+
+        waste(system(endCommand.c_str())); // put the end block tag in the stream
+
+        Getter::pMainForm->postDataReadyEvent(blockNo);
+        blockNo+=1;
+        
+        if (runState == RUNNING) QThread::msleep(500);
+        for (int wink=0; (wink < Getter::pMainForm->getNapTime()) && (runState == RUNNING); wink++) {
+            QThread::msleep(1000);        
+        }
+        if (runState != RUNNING) break; // exit the infinite while loop
     }
-    lineCommand += Getter::pMainForm->getCurrentInterface() + " scan >> " + pipeName;
-    for (int retries = 0; retries < 20; retries++) {
-        rcSysCall = system(lineCommand.c_str());
-        if ((rcSysCall == 0) || (closing)) break;
-        else QThread::msleep(500); // wait half a second and try again
-    }
-    if (rcSysCall !=0) { // retries exhausted on multiple failures
-        endCommand = "echo \"" + endBlockString + " -1\\n\" >> " + pipeName;
-        linssidLog << "Getter: command failed block " << blockNo << endl;
-    } else { // success!
-        endCommand = "echo \"" + endBlockString + cppIsStupid.str() + "\\n\" >> " + pipeName;
-        linssidLog << "Getter: block returned " << blockNo << endl;
-    }
-    waste(system(endCommand.c_str())); // put the end block tag in the stream
-    if (!closing) {
-        QThread::msleep(Getter::pMainForm->getNapTime() * 1000 + 500);
-    }
-    Getter::pMainForm->postDataReadyEvent(blockNo);
+    runState = STOPPED;
 }
 
 inline void Getter::waste(int) {
