@@ -8,6 +8,7 @@
 #include <iostream>
 #include <fstream>
 #include <string>
+#include <cstring>
 #include <sstream>
 #include <random>
 #include <climits>
@@ -21,10 +22,14 @@
 #include <QAbstractItemModel>
 #include <QMainWindow>
 #include <QMessageBox>
+#include <QFont>
 #include <qwt.h>
 #include <qwt_plot.h>
 #include <qwt_plot_curve.h>
 #include <qwt_plot_grid.h>
+#include <qwt_symbol.h>
+#include <qwt_plot_marker.h>
+#include <QPointF>
 #include <qwt_scale_draw.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -35,7 +40,6 @@
 #include "MainForm.h"
 #include "Getter.h"
 #include "AboutBox.h"
-#include "passBox.h"
 #include "prefsDialog.h"
 #include "ui_MainForm.h"
 
@@ -44,8 +48,12 @@ extern int lastBlockReceived;
 extern qint64 startTime;
 extern string endBlockString;
 extern string pipeName;
-extern ofstream linssidLog;
-extern bool closing;
+// extern ofstream linssidLog;
+extern runStates runstate;
+extern int realUID;
+extern struct passwd *realUser;
+extern string fullPrefsName;
+extern char* fullPrefsNameCstr;
 
 extern string genPipeName(int);
 
@@ -72,6 +80,7 @@ struct MainForm::cellData {
     int BW; // max BW in any protocol 20 or 40 or 80 or 160 MHz
     int cenChan; // center channel in 40/80/160 MHz bandwidths
     string vendor;
+    bool firstPlot;
     long firstSeen;
     long lastSeen;
     string netType;
@@ -79,9 +88,12 @@ struct MainForm::cellData {
     QwtPlotCurve* pBandCurve;
     double xPlot[4];
     double yPlot[4];
-    History* pHistory;
+    // see: http://www.qtcentre.org/threads/46316-Draw-a-single-point-into-a-qwt-plot
+    QwtPlotMarker* pCntlChanPlot; // to plot control channel marker
+    QwtSymbol* pChanSymbol;    
     QwtPlotCurve* pTimeCurve;
     QTableWidgetItem * pTableItem[MAX_TABLE_COLS];
+    History* pHistory;
     int timesSeen; // believe it or not, some drivers report a MAC more than once per scan
 };
 
@@ -96,7 +108,8 @@ struct MainForm::History {
 };
 
 struct MainForm::vendorStruct {
-    unsigned int ID;
+    uint64_t ID;
+    char blockMode;
     string name;
 };
 
@@ -118,8 +131,9 @@ struct MainForm::sMainsplit {
 };
 
 struct MainForm::sPlotprefs {
+    int fntSize;
     int plotlb;
-    int plutub;
+    int plotub;
     bool showgrid;
 };
 
@@ -182,6 +196,9 @@ QColor MainForm::qColorArray[NUMBER_OF_COLORS]
             Qt::cyan, Qt::magenta, Qt::gray, Qt::darkCyan, Qt::darkMagenta,
             Qt::darkYellow, Qt::darkGray
 };
+QFont MainForm::tblFnt( (const QString) "Arial", 11);
+QString MainForm::fntSizes[] = {"10", "11", "12", "14", "16"};
+int MainForm::numFntSizes = 5;
 QAction* MainForm::colToQAction[MAX_TABLE_COLS];
 int MainForm::columnWidth[MAX_TABLE_COLS]; // since Qt doesn't see fit to remember for us...
 QwtPlotGrid* MainForm::chan24Grid;
@@ -206,7 +223,7 @@ MainForm::sDefPref MainForm::defPref = {// default prefs defined here
     /* plottab  */ 0,
     /* naptime  */ 2,
     /* plotprefs*/
-    {-100, -20, 1},
+    {11, -100, -20, 1}, // added font size
     /* logdata */ 0
 };
 
@@ -242,7 +259,7 @@ MainForm::MainForm() {
     connect(MainForm::mainFormWidget.mainTableWidget->horizontalHeader(),
             SIGNAL(sectionResized(int, int, int)), this, SLOT(columnWidthSave(int, int, int)));
 
-    MainForm::cellDataRay.reserve(15); // expect about 15 cells to be found. More or less is OK.
+    MainForm::cellDataRay.reserve(50); // expect about 50 cells to be found. More or less is OK.
     lastBlockRequested = 0; // these global variables should be made protected
     lastBlockReceived = 0;
     startTime = QDateTime::currentMSecsSinceEpoch();
@@ -255,7 +272,6 @@ MainForm::~MainForm() {
 
 void MainForm::init() {
     srand(time(NULL)); //initialize the random number generator seed
-    MainForm::getUserID(); // will exit here if needed and can't get
     MainForm::addInterfaces(); // find the wifi interface names and add them to the comboBox
     MainForm::setInterface(0); // set the interface select arbitrarily to 0
     MainForm::maxTableIndex = -1;
@@ -332,13 +348,11 @@ void MainForm::loadVendorDb() {
     // load vendor array with ID and name
     MainForm::vendor = new MainForm::vendorStruct[MainForm::numVendors];
     int vRecNo = 0;
-    istringstream tempStream;
     getline(vendorFile, tempString); // clear the end of line above
     while (getline(vendorFile, tempString)) {
-        tempStream.str(tempString.substr(0, 6));
-        tempStream.clear();
-        tempStream >> hex >> MainForm::vendor[vRecNo].ID;
-        MainForm::vendor[vRecNo].name = tempString.substr(6);
+        MainForm::vendor[vRecNo].ID = strtol(tempString.substr(0,9).c_str(), nullptr, 16);
+        MainForm::vendor[vRecNo].blockMode = tempString[9];
+        MainForm::vendor[vRecNo].name = tempString.substr(10);
         vRecNo++;
     }
     vendorFile.close();
@@ -348,12 +362,18 @@ string MainForm::findVendor(string MACaddr) {
     int left = 0;
     int right = MainForm::numVendors - 1;
     int mid;
-    istringstream convert(MACaddr.substr(0, 2) + MACaddr.substr(3, 2) + MACaddr.substr(6, 2));
-    unsigned int key;
-    convert >> hex >> key;
+    uint64_t key;
+    uint64_t mask;
+    char blockType;
+    key = strtol((MACaddr.substr(0, 2) + MACaddr.substr(3, 2) + MACaddr.substr(6, 2)
+            + MACaddr.substr(9,2) + MACaddr.substr(12,1)).c_str(), nullptr, 16);
     while (left <= right) {
         mid = (int) ((left + right) / 2);
-        if (key == MainForm::vendor[mid].ID) {
+        blockType = MainForm::vendor[mid].blockMode;
+        if (blockType == 'L') mask = ~0x0000000000000FFF;
+        else if (blockType == 'M') mask = ~0x00000000000000FF;
+        else mask = ~0x0000000000000000; // block type Small
+        if ((key & mask) == MainForm::vendor[mid].ID) {
             return MainForm::vendor[mid].name;
         } else if (key > MainForm::vendor[mid].ID)
             left = mid + 1;
@@ -363,43 +383,12 @@ string MainForm::findVendor(string MACaddr) {
     return "<unrecognized>";
 }
 
-void MainForm::getUserID() {
-    // must get userid to get full interface scan
-    if (geteuid() == 0) {
-        pwStatus = NOTNEEDED; // must be running as root or with root privilege
-    } else {
-        passBox pwDialog1;
-        for (int pwTry = 0; pwTry < 3; pwTry++) {
-            if (pwTry == 0) pwDialog1.setPassPrompt("First shot:");
-            else if (pwTry == 1) pwDialog1.setPassPrompt("Second try:");
-            else pwDialog1.setPassPrompt("Last chance!");
-            // pwDialog1.show();
-            pwDialog1.exec();
-            if (pwStatus == CANCELLED) {
-                MainForm::mainFormWidget.runBtn->setChecked(false);
-                //return;
-                break;
-            }
-            if (pwStatus == GOOD) break;
-        }
-        if (pwStatus == BAD || pwStatus == CANCELLED) {
-            MainForm::mainFormWidget.runBtn->setChecked(false);
-            QMessageBox::warning(0, "password fail", "Unable to verify password");
-            exit(1);
-        }
-    }
-}
-
 void MainForm::addInterfaces() {
     string somePipeName = genPipeName(10);
     string eof = "###EOF###";
     mkfifo(somePipeName.c_str(), 0666);
     static fstream ifs(somePipeName);
     string commandLine = "iw dev >> " + somePipeName;
-    if (pwStatus == GOOD) {
-        commandLine = "echo \'" + password + "\' | sudo -kS -p \"\" " + commandLine;
-        //        cout << commandLine + "\n";
-    }
     if (system(commandLine.c_str()) == 0) {
         commandLine = "echo \'" + eof + "\' >> " + somePipeName;
         waste(system(commandLine.c_str()));
@@ -408,7 +397,6 @@ void MainForm::addInterfaces() {
         boost::smatch sm;
         boost::regex rx("^[ \\t]+Interface +([^ ]+) *");
         while (getline(ifs, interfaceLine) && interfaceLine != eof) {
-            //            cout << interfaceLine + "\n";
             if (boost::regex_match(interfaceLine, sm, rx))
                 mainFormWidget.interfaceCbx->addItem(QString::fromStdString(sm[1]));
         }
@@ -422,10 +410,6 @@ void MainForm::addInterfaces() {
     // Now repeat the whole mess because linux wifi drivers can't decide where to announce themselves
     //
     commandLine = "cat /proc/net/wireless >> " + somePipeName;
-    if (pwStatus == GOOD) {
-        commandLine = "echo \'" + password + "\' | sudo -kS -p \"\" " + commandLine;
-        //        cout << commandLine + "\n";
-    }
     if (system(commandLine.c_str()) == 0) {
         commandLine = "echo \'" + eof + "\' >> " + somePipeName;
         waste(system(commandLine.c_str()));
@@ -434,7 +418,6 @@ void MainForm::addInterfaces() {
         boost::smatch sm2;
         boost::regex rx2("^ *([0-9A-Za-z_-]+) *:.+");
         while (getline(ifs, interfaceLine) && interfaceLine != eof) {
-            //            cout << interfaceLine + "\n";
             if (boost::regex_match(interfaceLine, sm2, rx2)) {
                 interface = QString::fromStdString(sm2[1]);
                 bool found = false;
@@ -492,14 +475,17 @@ int MainForm::getNapTime() {
     return MainForm::mainFormWidget.napTimeSlider->value();
 }
 
-void MainForm::updatePlotPrefs(int plotMin, int plotMax, bool showGrid) {
+void MainForm::updatePlotPrefs(QString tblFntSize, int plotMin, int plotMax, bool showGrid) {
     // a slot called from the prefs dialog to dynamically update the plots
+    // MainForm::mainFormWidget.mainTableWidget->setFont(tblFntSize,"Ariel");
+    MainForm::tblFnt.setPointSize(tblFntSize.toInt());
     MainForm::mainFormWidget.timePlot->setAxisScale(QwtPlot::yLeft, plotMin, plotMax, 20);
     MainForm::mainFormWidget.chan24Plot->setAxisScale(QwtPlot::yLeft, plotMin, plotMax, 20);
     MainForm::mainFormWidget.chan5Plot->setAxisScale(QwtPlot::yLeft, plotMin, plotMax, 20);
     MainForm::timeGrid->enableY(showGrid);
     MainForm::chan24Grid->enableY(showGrid);
     MainForm::chan5Grid->enableY(showGrid);
+    MainForm::reDrawTable();
     MainForm::mainFormWidget.timePlot->replot();
     MainForm::mainFormWidget.chan24Plot->replot();
     MainForm::mainFormWidget.chan5Plot->replot();
@@ -510,10 +496,15 @@ void MainForm::logPrefChanged(int state) {
 }
 
 void MainForm::writePrefsFile() {
-    struct passwd *pw = getpwuid(getuid());
-    const char *homeDir = pw->pw_dir;
+    // struct passwd *pw = getpwuid(getuid());
+    // const char *homeDir = pw->pw_dir;
+    // onst char *homeDir = realUser->pw_dir;
+    extern string fullPrefsName;
+    extern char* fullPrefsNameCstr;
     ofstream prefs;
-    prefs.open(string(homeDir) + "/" + string(PREFS_FILE_NAME), ios::out);
+    prefs.open(fullPrefsName, ios::out);
+    waste(chown(fullPrefsNameCstr, realUser->pw_uid, realUser->pw_gid));
+    chmod(fullPrefsNameCstr, 00644);
     prefs << "version " << LINSSIDPREFSVER << endl;
     // col number must match the enum in "custom.h"
     prefs << "colwidth";
@@ -543,6 +534,7 @@ void MainForm::writePrefsFile() {
     prefs << "plottab " << MainForm::mainFormWidget.mainTabWgt->currentIndex() << endl;
     prefs << "naptime " << MainForm::mainFormWidget.napTimeSlider->value() << endl;
     prefs << "plotprefs "
+            << MainForm::tblFnt.pointSize() << " "
             << int(MainForm::mainFormWidget.timePlot->axisScaleDiv(QwtPlot::yLeft).lowerBound()) << " "
             << int(MainForm::mainFormWidget.timePlot->axisScaleDiv(QwtPlot::yLeft).upperBound()) << " "
             << MainForm::timeGrid->yEnabled() << endl;
@@ -550,12 +542,15 @@ void MainForm::writePrefsFile() {
     prefs.close();
 }
 
-void MainForm::writePrefsBlock(string absPrefsFileName, MainForm::sDefPref prefBlock) {
+void MainForm::writePrefsBlock(MainForm::sDefPref prefBlock) {
     // Writes a block of preferences of the structure sDefPref struct.
     // At entry, the file must either not exist or be closed.
     // At exit, the newly written file will be closed.
+    extern string fullPrefsName;
     fstream prefs;
-    prefs.open(absPrefsFileName, ios::out);
+    prefs.open(fullPrefsName, ios::out);
+    waste(chown(fullPrefsNameCstr, realUser->pw_uid, realUser->pw_gid));
+    chmod(fullPrefsNameCstr, 00644);
     prefs << "version " << LINSSIDPREFSVER << endl;
     prefs << "colwidth";
     for (int i = 0; i < MAX_TABLE_COLS; i++)
@@ -579,22 +574,25 @@ void MainForm::writePrefsBlock(string absPrefsFileName, MainForm::sDefPref prefB
             << " " << prefBlock.mainsplit.bottomheight << endl;
     prefs << "plottab " << prefBlock.plottab << endl;
     prefs << "naptime " << prefBlock.naptime << endl;
-    prefs << "plotprefs " << prefBlock.plotprefs.plotlb
-            << " " << prefBlock.plotprefs.plutub
-            << " " << prefBlock.plotprefs.showgrid << endl;
+    prefs << "plotprefs " << prefBlock.plotprefs.fntSize
+            << " " << prefBlock.plotprefs.plotlb
+            << " " << prefBlock.plotprefs.plotub
+            << " " << prefBlock.plotprefs.showgrid
+            << endl;
     prefs << "logdata " << prefBlock.logData << endl;
     prefs.close();
 }
 
 void MainForm::readPrefsFile() {
-    struct passwd *pw = getpwuid(getuid());
-    const char *homeDir = pw->pw_dir;
-    string absPrefsFileName = string(homeDir) + "/" + string(PREFS_FILE_NAME);
+    // struct passwd *pw = getpwuid(getuid());
+    // const char *homeDir = pw->pw_dir;
+    // string absPrefsFileName = string(homeDir) + "/" + string(PREFS_FILE_NAME);
+    extern string fullPrefsName;
     fstream prefs;
-    prefs.open(absPrefsFileName, ios::in);
+    prefs.open(fullPrefsName, ios::in);
     if (!prefs.is_open()) { // no prefs file, so create new with default values
-        writePrefsBlock(absPrefsFileName, MainForm::defPref);
-        prefs.open(absPrefsFileName, ios::in);
+        writePrefsBlock(MainForm::defPref);
+        prefs.open(fullPrefsName, ios::in);
     }
     // make sure right version
     string line, tag, vers;
@@ -610,8 +608,8 @@ void MainForm::readPrefsFile() {
     }
     if (vers != LINSSIDPREFSVER) { // old version so trash and replace with defaults
         prefs.close();
-        writePrefsBlock(absPrefsFileName, MainForm::defPref);
-        prefs.open(absPrefsFileName, ios::in);
+        writePrefsBlock(MainForm::defPref);
+        prefs.open(fullPrefsName, ios::in);
     }
     // have a prefs file so parse
     prefs.seekg(0);
@@ -677,17 +675,22 @@ void MainForm::readPrefsFile() {
             lineParse >> napTime;
             MainForm::mainFormWidget.napTimeSlider->setValue(napTime);
         } else if (tag == "plotprefs") {
+            int fntSize;
             int plotLb, plotUb;
             bool showGrid;
-            lineParse >> plotLb >> plotUb >> showGrid;
+            lineParse >> fntSize >> plotLb >> plotUb >> showGrid;
             // validate or the mess gets big
             if ((plotLb < -100) || (plotUb > 0) || (plotUb < (plotLb + 10))) { // prefs were hosed
                 plotLb = -100;
                 plotUb = -20; // so reset them to nominal values
             }
+            if ((fntSize < 10) || (fntSize > 16)) fntSize = 11; // reset to nominal
+            
             MainForm::mainFormWidget.timePlot->setAxisScale(QwtPlot::yLeft, plotLb, plotUb, 20);
             MainForm::mainFormWidget.chan24Plot->setAxisScale(QwtPlot::yLeft, plotLb, plotUb, 20);
             MainForm::mainFormWidget.chan5Plot->setAxisScale(QwtPlot::yLeft, plotLb, plotUb, 20);
+            MainForm::tblFnt.setPointSize(fntSize);
+            MainForm::mainFormWidget.mainTableWidget->setFont(tblFnt);
             MainForm::timeGrid->enableY(showGrid);
             MainForm::chan24Grid->enableY(showGrid);
             MainForm::chan5Grid->enableY(showGrid);
@@ -704,19 +707,24 @@ void MainForm::postDataReadyEvent(const int customData1) {
 }
 
 void MainForm::doRun() {
+    extern runStates runState;
     if (MainForm::mainFormWidget.runBtn->isChecked()) {
         if (firstScan) {
             firstScan = false;
             MainForm::runStartTime = time(NULL);
         }
         MainForm::mainFormWidget.statusTxt->setText("Scanning ...");
+        runState = RUNNING;
         MainForm::pGetter->Getter::postDataWantedEvent(++lastBlockRequested);
         MainForm::drawTable();
         MainForm::drawChan24Plot();
         MainForm::drawChan5Plot();
         MainForm::drawTimePlot();
     } else {
-        MainForm::mainFormWidget.statusTxt->setText("Waiting for wifi to terminate scan ...");    
+        if (runState != STOPPED) runState = STOPPING;
+        MainForm::mainFormWidget.statusTxt->setText("Waiting for wifi to terminate scan ...");
+        while (runState != STOPPED) usleep(500 * 1000); // wait half a second and try again
+        MainForm::mainFormWidget.statusTxt->setText("Paused ...");
     }
 }
 
@@ -749,14 +757,13 @@ void MainForm::reDrawTable() {
 
 void MainForm::showAboutBox() {
     AboutBox aboutBox1;
-//    aboutBox1.show();
     aboutBox1.exec();
-//    aboutBox1.raise();
 }
 
 void MainForm::showPrefsDlg() {
     if (MainForm::prefsDlg1 != 0) return; // already a prefs dialog open somewhere...
     MainForm::prefsDlg1 = new prefsDialog(
+            QString::number(MainForm::tblFnt.pointSize()),
             int(MainForm::mainFormWidget.timePlot->axisScaleDiv(QwtPlot::yLeft).lowerBound()),
             int(MainForm::mainFormWidget.timePlot->axisScaleDiv(QwtPlot::yLeft).upperBound()),
             MainForm::timeGrid->yEnabled(),
@@ -784,17 +791,18 @@ void MainForm::customEvent(QEvent * event) {
 }
 
 void MainForm::closeEvent(QCloseEvent * event) {
-//    cout << "closeEvent intercepted..." << endl;
-    closing = true; // don't let Getter take a nap
+    extern runStates runState;
+    if (runState == RUNNING) runState = STOPPING; // tell getter to stop what it's doing
     MainForm::mainFormWidget.statusTxt->setText("Exiting, waiting for wifi driver ...");
     MainForm::mainFormWidget.statusTxt->repaint();
+    while (runState != STOPPED) usleep(500 * 1000); // wait until getter is stopped
     pGetterThread->QThread::quit();
     writePrefsFile();
     pGetterThread->QThread::wait();
     MainForm::mainFormWidget.statusTxt->setText("Closing ...");
     MainForm::mainFormWidget.statusTxt->repaint();
     remove(pipeName.c_str());
-    linssidLog.close();
+//    linssidLog.close();
     if (MainForm::logDataStream.is_open()) MainForm::logDataStream.close();
     //    QMainWindow::closeEvent(event);
     event->accept();
@@ -802,7 +810,6 @@ void MainForm::closeEvent(QCloseEvent * event) {
 }
 
 void MainForm::drawTable() {
-    //    QMessageBox::information(0, "checkpoint", "entered drawTable");
 
     MainForm::mainFormWidget.mainTableWidget->setColumnCount(MAX_TABLE_COLS);
     MainForm::mainFormWidget.mainTableWidget->setRowCount(MainForm::maxTableIndex + 1);
@@ -864,6 +871,9 @@ void MainForm::setVisibleCols() {
 }
 
 void MainForm::fillTable() {
+    
+    MainForm::mainFormWidget.mainTableWidget->setFont(tblFnt);
+    
     // fill in the x-y, also set each cell text alignment
     MainForm::mainFormWidget.mainTableWidget->setRowCount(maxTableIndex + 1);
     for (int row = 0; row <= maxTableIndex; row++) {
@@ -985,7 +995,30 @@ void MainForm::fillPlots() {
             MainForm::blockSampleTime - TIME_PLOT_SCALE,
             MainForm::blockSampleTime, 10);
     for (int tbi = 0; tbi <= maxTableIndex; tbi++) {
-        // first the 2.5GHz and 5GHz channel vs signal plots
+        // first attach plots plots we couldn't before because of sparse data
+        if (MainForm::cellDataRay[tbi].pTableItem[PLOT]->checkState() == Qt::Checked) {
+            MainForm::cellDataRay[tbi].pChanSymbol->setStyle(QwtSymbol::Diamond);
+            MainForm::cellDataRay[tbi].pChanSymbol->setColor(MainForm::cellDataRay[tbi].color);
+            MainForm::cellDataRay[tbi].pChanSymbol->setSize(10, 10);
+            if (MainForm::cellDataRay[tbi].firstPlot) {
+                resolveMesh(tbi);
+                if (MainForm::cellDataRay[tbi].frequency.substr(0, 1) == "2") {
+                    MainForm::cellDataRay[tbi].pBandCurve->attach(MainForm::mainFormWidget.chan24Plot);
+                    if (MainForm::cellDataRay[tbi].BW >= 40) 
+                        MainForm::cellDataRay[tbi].pCntlChanPlot->attach(MainForm::mainFormWidget.chan24Plot);
+                } else {
+                    MainForm::cellDataRay[tbi].pBandCurve->attach(MainForm::mainFormWidget.chan5Plot);
+                    if (MainForm::cellDataRay[tbi].BW >= 40) {
+                        MainForm::cellDataRay[tbi].pCntlChanPlot->attach(MainForm::mainFormWidget.chan5Plot);
+                    }
+                }
+                MainForm::cellDataRay[tbi].firstPlot = false;
+            }
+        } else {
+            MainForm::cellDataRay[tbi].pChanSymbol->setStyle(QwtSymbol::NoSymbol);
+        }
+        
+        // then the 2.5GHz and 5GHz channel vs signal plots
         float spread = MainForm::cellDataRay[tbi].BW / 10.0;
         MainForm::cellDataRay[tbi].xPlot[0] = MainForm::cellDataRay[tbi].cenChan - spread;
         MainForm::cellDataRay[tbi].xPlot[1] = MainForm::cellDataRay[tbi].cenChan - spread + 1.0;
@@ -997,6 +1030,11 @@ void MainForm::fillPlots() {
         if (MainForm::cellDataRay[tbi].pTableItem[PLOT]->checkState() == Qt::Checked) {
             MainForm::cellDataRay[tbi].pBandCurve->setRawSamples(MainForm::cellDataRay[tbi].xPlot,
                     MainForm::cellDataRay[tbi].yPlot, 4);
+            if (MainForm::cellDataRay[tbi].BW >= 40) { // here we plot a point for the control channel
+                MainForm::cellDataRay[tbi].pCntlChanPlot->setValue( 
+                    QPointF( (float) MainForm::cellDataRay[tbi].channel, 
+                    MainForm::cellDataRay[tbi].signal ) );
+            }
         } else {
             MainForm::cellDataRay[tbi].pBandCurve->setSamples(0, 0, 0);
         }
@@ -1025,6 +1063,29 @@ void MainForm::fillPlots() {
     MainForm::mainFormWidget.timePlot->replot();
 }
 
+void MainForm::resolveMesh(int tbi) {
+    string search24 = MainForm::cellDataRay[tbi].macAddr.substr(9);
+    if (MainForm::cellDataRay[tbi].essid == "<hidden>") {
+        for (int tbi2 = 0; tbi2 <= MainForm::maxTableIndex; tbi2++) {
+            if (MainForm::cellDataRay[tbi2].macAddr.substr(9) == search24 &&
+                    MainForm::cellDataRay[tbi2].essid != "<hidden>" &&
+                    MainForm::cellDataRay[tbi2].essid.substr(0,6) != "<mesh ") {
+                MainForm::cellDataRay[tbi].essid = "<mesh " + 
+                MainForm::cellDataRay[tbi2].essid + ">";
+                break;
+            }
+        }
+    } else { // essid is not "<hidden>", so search for hiddens to resolve
+        for (int tbi2 = 0; tbi2 <= MainForm::maxTableIndex; tbi2++) {
+            if (MainForm::cellDataRay[tbi2].essid == "<hidden>" &&
+                    MainForm::cellDataRay[tbi2].macAddr.substr(9) == search24) {
+                MainForm::cellDataRay[tbi2].essid = "<mesh " + 
+                MainForm::cellDataRay[tbi].essid + ">";
+            }
+        }
+    }
+}
+
 void MainForm::initNewCell(string macAddress, int tbi) {
     // Initialize a newly found cell.
     MainForm::cellData* emptyStruct;               // C++ is really stupid
@@ -1036,6 +1097,7 @@ void MainForm::initNewCell(string macAddress, int tbi) {
     MainForm::cellDataRay[tbi].minSignal = 0;
     MainForm::cellDataRay[tbi].maxSignal = -120;
     MainForm::cellDataRay[tbi].firstSeen = now;
+    MainForm::cellDataRay[tbi].firstPlot = true;
     MainForm::cellDataRay[tbi].protocol = "unknown";
     MainForm::cellDataRay[tbi].vendor = MainForm::findVendor(macAddress);
     MainForm::cellDataRay[tbi].pHistory = new History(); // give it a history
@@ -1048,6 +1110,12 @@ void MainForm::initNewCell(string macAddress, int tbi) {
     MainForm::cellDataRay[tbi].pBandCurve = new QwtPlotCurve("");
     MainForm::cellDataRay[tbi].pBandCurve->setPen(* new QPen(MainForm::cellDataRay[tbi].color, 3.0));
     MainForm::cellDataRay[tbi].pBandCurve->setRenderHint(QwtPlotItem::RenderAntialiased);
+    MainForm::cellDataRay[tbi].pCntlChanPlot = new QwtPlotMarker(); // create plot for control channel symbol
+    MainForm::cellDataRay[tbi].pChanSymbol = new QwtSymbol();
+    MainForm::cellDataRay[tbi].pChanSymbol->setStyle(QwtSymbol::Diamond);
+    MainForm::cellDataRay[tbi].pChanSymbol->setColor(tempColor);
+    MainForm::cellDataRay[tbi].pChanSymbol->setSize(10, 10);
+    MainForm::cellDataRay[tbi].pCntlChanPlot->setSymbol(MainForm::cellDataRay[tbi].pChanSymbol);
     // attaching plot curve waits 'till know frequency
     MainForm::mainFormWidget.mainTableWidget->setRowCount(tbi + 1);
     for (int ix = 0; ix < MAX_TABLE_COLS; ix++) {
@@ -1061,9 +1129,8 @@ void MainForm::initNewCell(string macAddress, int tbi) {
     MainForm::cellDataRay[tbi].pTableItem[SSID]->setTextColor(MainForm::cellDataRay[tbi].color);
 }
 
-void MainForm::extractData(string tl, int &tbi) {
+void MainForm::extractData(string tl, int &tbi, int &newBSS) {
     // extract the information from each line recovered from the pipe from getter
-    static int newBSS;
     boost::smatch sm;
     if (boost::regex_match(tl, sm, boost::regex("^BSS.*?(([A-Fa-f0-9]{2}:){5}[A-Fa-f0-9]{2}).*",
           boost::regex_constants::icase))) {
@@ -1093,7 +1160,9 @@ void MainForm::extractData(string tl, int &tbi) {
     } 
        else if (boost::regex_match(tl, sm, boost::regex("^.+?SSID: +(.*)"))) {
         string tempSSID = sm[1];
-        MainForm::cellDataRay[tbi].essid = tempSSID;
+        if (MainForm::cellDataRay[tbi].essid == "<hidden>" && tempSSID != "") {
+            MainForm::cellDataRay[tbi].essid = tempSSID;
+        }
     }  else if (boost::regex_match(tl, sm, boost::regex(
             "^[ \\t]+Supported rates: (.*)", boost::regex_constants::icase))) { // protocol
         string tempStr = sm[1];
@@ -1134,13 +1203,6 @@ void MainForm::extractData(string tl, int &tbi) {
             boost::regex_constants::icase))) {
         string tempFreq = sm[1];
         MainForm::cellDataRay[tbi].frequency = tempFreq;
-        if (newBSS) {
-            if (tempFreq.substr(0, 1) == "2") {
-                MainForm::cellDataRay[tbi].pBandCurve->attach(MainForm::mainFormWidget.chan24Plot);
-            } else {
-                MainForm::cellDataRay[tbi].pBandCurve->attach(MainForm::mainFormWidget.chan5Plot);
-            }
-        }
     } else if (boost::regex_match(tl, sm, boost::regex("^.*?signal:.*?([\\-0-9]+).*?dBm.*",
             boost::regex_constants::icase))) {
             string tempSig = sm[1];
@@ -1205,24 +1267,28 @@ void MainForm::extractData(string tl, int &tbi) {
 } // extractData()
 
 void MainForm::doLogData() {
+    extern string fullLogName;
+    extern char* fullLogNameCstr;
     if (!MainForm::logDataStream.is_open()) { // if data log file is not open...
-        struct passwd *pw = getpwuid(getuid());
-        const char *homeDir = pw->pw_dir;
-        string logDataFileName = string(homeDir) + "/" + string(LOG_DATA_FILE_NAME);
-        MainForm::logDataStream.open(logDataFileName, ios::in); // open for read to see if file already exists
+        // struct passwd *pw = getpwuid(getuid());
+        // const char *homeDir = pw->pw_dir;
+        // string logDataFileName = string(homeDir) + "/" + string(LOG_DATA_FILE_NAME);
+        MainForm::logDataStream.open(fullLogName, ios::in); // open for read to see if file already exists
         if (MainForm::logDataStream) { // if it exists.,..
             string arg1 = ""; string arg2 = "";
             logDataStream >> arg1 >> arg2;
             if (arg1 != "LINSSIDDATALOGVER" || arg2 != LINSSIDDATALOGVER) { // old log file version
                 MainForm::logDataStream.close(); // close it for read
-                rename(logDataFileName.c_str(), (logDataFileName + ".old").c_str());
-                writeLogDataHeader(logDataFileName); // open a new file for write append, insert header
+                rename(fullLogNameCstr, (fullLogName + ".old").c_str());
+                writeLogDataHeader(); // open a new file for write append, insert header
             } else {  // is new log format so open for write append
                 MainForm::logDataStream.close(); // close it for read
-                MainForm::logDataStream.open(logDataFileName, ios::out | ios::app);
+                MainForm::logDataStream.open(fullLogName, ios::out | ios::app);
+                waste(chown(fullLogNameCstr, realUser->pw_uid, realUser->pw_gid));
+                chmod(fullLogNameCstr, 00644);
             }
         } else { // if not exists... open for append and write headers
-            writeLogDataHeader(logDataFileName);
+            writeLogDataHeader();
         }
     }
     // now write data
@@ -1249,13 +1315,17 @@ void MainForm::doLogData() {
                 << MainForm::cellDataRay[tbi].cenChan << "\t"
                 << firstStr << "\t"
                 << lastStr << "\t"
-                << "\"" << MainForm::cellDataRay[tbi].vendor << "\"\n";
+                << "\"" << MainForm::cellDataRay[tbi].vendor << "\"" << endl;
     }
 }
 
-void MainForm::writeLogDataHeader(string logDataFileName) {
+void MainForm::writeLogDataHeader() {
+    extern string fullLogName;
+    extern char* fullLogNameCstr;
     MainForm::logDataStream.close(); // close it for read if was open (don't really need to...)
-    MainForm::logDataStream.open(logDataFileName, ios::out | ios::app); // open for write append
+    MainForm::logDataStream.open(fullLogName, ios::out | ios::app); // open for write append
+    waste(chown(fullLogNameCstr, realUser->pw_uid, realUser->pw_gid));
+    chmod(fullLogNameCstr, 00644);
     MainForm::logDataStream << "LINSSIDDATALOGVER " << LINSSIDDATALOGVER << "\n";
     MainForm::logDataStream << "Time\tSSID\tMAC\tChannel\tMode\tProtocol\tSecurity\tPrivacy\t\
 Cipher\tFrequency\tQuality\tSignal\tBW\tMin_Sig\tMax_Sig\tCen_Chan\tFirst_Seen\tLast_Seen\tVendor\n";
@@ -1264,6 +1334,8 @@ Cipher\tFrequency\tQuality\tSignal\tBW\tMin_Sig\tMax_Sig\tCen_Chan\tFirst_Seen\t
 void MainForm::handleDataReadyEvent(const DataReadyEvent * /*event*/) {
     // Now something can be safely done with the Qt objects.
     // Access the custom data using event->getReadyBlockNo() etc.
+    extern runStates runState;
+    static int newBSS;
     QCoreApplication::processEvents(QEventLoop::AllEvents); // TODO is this necessary?
 
     static fstream thePipe(pipeName);
@@ -1272,27 +1344,27 @@ void MainForm::handleDataReadyEvent(const DataReadyEvent * /*event*/) {
         MainForm::cellDataRay[ix].protocol = "";
         MainForm::cellDataRay[ix].signal = -110;
         MainForm::cellDataRay[ix].timesSeen = 0;
-        // MainForm::cellDataRay[ix].BW = 20; // no bandwidth less than 20 MHz
     }
     // disable column sorting to prevent segfaults while we muck with the table
     MainForm::mainFormWidget.mainTableWidget->setSortingEnabled(false);
     string tempLine;
     bool lastLine = false;
+    int block;
     MainForm::now = time(NULL);
     MainForm::blockSampleTime = now - MainForm::runStartTime;
     int tableIndex = -1; // holds current index pointer into cellData
     while (!lastLine && getline(thePipe, tempLine)) {
-        // cout << "tempLine:" << tempLine << endl; //debug
-        MainForm::extractData(tempLine, tableIndex); // the heavy lifting here
+        MainForm::extractData(tempLine, tableIndex, newBSS); // the heavy lifting here
         lastLine = tempLine.substr(0, endBlockString.length()) == endBlockString;
         if (lastLine) {
-            int block = atoi(tempLine.substr(endBlockString.length() + 1, std::string::npos).c_str());
+            block = atoi(tempLine.substr(endBlockString.length() + 1, std::string::npos).c_str());
             if (block >= 0) lastBlockReceived = block;
-            if (MainForm::mainFormWidget.runBtn->isChecked()) {
+            if ( MainForm::mainFormWidget.runBtn->isChecked()) {
+                runState = RUNNING;
                 if (block >= 0) lastBlockRequested++;
-                MainForm::pGetter->postDataWantedEvent(lastBlockRequested);
             } else {
                 MainForm::mainFormWidget.statusTxt->setText("Paused");
+                if (runState == RUNNING) runState = STOPPING;
             }
             if (block >= 0) {
                 MainForm::fillTable();
@@ -1300,8 +1372,11 @@ void MainForm::handleDataReadyEvent(const DataReadyEvent * /*event*/) {
                 if (MainForm::logDataState == Qt::Checked) {
                     doLogData();
                 }
+
             }
+            
         }
+        
     }
 }
 
@@ -1335,3 +1410,18 @@ int MainForm::MinIntStr(const string &s) {
     }
     return retInt;
 }
+
+// string trimming
+//void MainForm::trimRight( std::string& str )
+//{
+//    const std::string whiteSpaces( " \f\n\r\t\v" );
+//    std::string::size_type pos = str.find_last_not_of( whiteSpaces );
+//    str.erase( pos + 1 );    
+//}
+//
+//void MainForm::trimLeft( std::string& str )
+//{
+//    const std::string whiteSpaces( " \f\n\r\t\v" );
+//    std::string::size_type pos = str.find_first_not_of( whiteSpaces );
+//    str.erase( pos + 1 );    
+//}
\ No newline at end of file
