@@ -12,6 +12,7 @@
 #include <fstream>
 #include <QEvent>
 #include <QString>
+#include <QFont>
 #include <qwt.h>
 #include <qwt_plot.h>
 #include <qwt_plot_curve.h>
@@ -19,7 +20,6 @@
 #include <qwt_scale_draw.h>
 #include "ui_MainForm.h"
 #include "prefsDialog.h"
-#include "passBox.h"
 #include "Custom.h"
 using namespace std;
 
@@ -49,7 +49,7 @@ public:
     void setInterface(int);
     int getNapTime();
     void writePrefsFile();
-    void writePrefsBlock(string, sDefPref);
+    void writePrefsBlock(sDefPref);
     void readPrefsFile();
     string getCurrentInterface();
     static const QEvent::Type DATA_READY_EVENT;
@@ -68,12 +68,15 @@ public:
     void drawTimePlot();
     void fillPlots();
     void initNewCell(string, int);
-    void extractData(string, int &);
+    void extractData(string, int &, int &);
     void doLogData();
-    void writeLogDataHeader(string);
+    void writeLogDataHeader();
     int MaxIntStr(const string&);
     int MinIntStr(const string&);
     inline void waste(int);
+    void resolveMesh(int);
+    // void trimRight( string& );
+    // void trimLeft( string& );
 
     static Getter* pGetter; // a pointer to the instance of the Getter that calls this MainForm
     static QThread* pGetterThread; // a pointer to the getter's thread
@@ -93,6 +96,9 @@ public:
     static string chan24Freq[15];
     static string chan50Freq[42][2];
     static QColor qColorArray[NUMBER_OF_COLORS];
+    static QFont tblFnt;
+    static QString fntSizes[];
+    static int numFntSizes;
     static QAction* colToQAction[MAX_TABLE_COLS];
     static int columnWidth[MAX_TABLE_COLS];
     static QwtPlotGrid* chan24Grid;
@@ -110,7 +116,7 @@ public slots:
     void showAboutBox();
     void showPrefsDlg();
     void columnWidthSave(int, int, int);
-    void updatePlotPrefs(int, int, bool);
+    void updatePlotPrefs(QString, int, int, bool);
     void logPrefChanged(int);
 
 protected:
